@@ -6,6 +6,6 @@ class ManticoreWhereNode(WhereNode):
     def as_sql(self, compiler, connection):
         sql, params = super().as_sql(compiler, connection)
         # remove one parentheses level
-        if sql[0] == '(' and sql[-1] == ')':
+        if sql and sql[0] == '(' and sql[-1] == ')':
             sql = sql[1:-1]
         return sql, params
